@@ -19,11 +19,9 @@
 
 #include <gtk/gtk.h>
 #include <gtkdatabox.h>
+#include <gtkdatabox_points.h>
+#include <gtkdatabox_grid.h>
 #include <math.h>
-/* Some versions of math.h have a PI problem... */
-#ifndef PI
-#define PI 3.14159265358979323846
-#endif
 
 #define POINTS 2000
 
@@ -40,8 +38,9 @@ create_grid (void)
    GtkWidget *close_button;
    GtkWidget *box;
    GtkWidget *label;
+   GtkWidget *table;
    GtkWidget *separator;
-   gint index;
+   GtkDataboxGraph *graph;
    gfloat *X;
    gfloat *Y;
    GdkColor color;
@@ -53,7 +52,8 @@ create_grid (void)
    g_signal_connect (GTK_OBJECT (window), "destroy",
 		     GTK_SIGNAL_FUNC (gtk_main_quit), NULL);
 
-   gtk_window_set_title (GTK_WINDOW (window), "GtkDatabox: Grid Example");
+   gtk_window_set_title (GTK_WINDOW (window),
+			 "GtkDatabox: Double Grid Example");
    gtk_container_set_border_width (GTK_CONTAINER (window), 0);
 
    box1 = gtk_vbox_new (FALSE, 0);
@@ -61,64 +61,67 @@ create_grid (void)
 
    label =
       gtk_label_new
-      ("Just to show how a grid could look like...\nOf course you can change the colour,\nthe number of vertical and horizontal lines\nthe line width...\nYou could even add more grids. Have fun.\n\nFor basic understanding see basics :-)");
+      ("This is an example of two grids\nLove it or hate it.\nI love it...\n\nFor basic understanding see basics :-)");
    gtk_box_pack_start (GTK_BOX (box1), label, FALSE, FALSE, 0);
    separator = gtk_hseparator_new ();
    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, FALSE, 0);
 
-   box = gtk_databox_new ();
-   g_signal_connect (GTK_OBJECT (box), "destroy",
-		     GTK_SIGNAL_FUNC (gtk_databox_data_destroy_all), NULL);
+   /* Create a GtkDatabox widget along with scrollbars and rulers */
+   gtk_databox_create_box_with_scrollbars_and_rulers (&box, &table, 
+                                                      TRUE, TRUE,
+                                                      TRUE, TRUE);
+   gtk_box_pack_start (GTK_BOX (box1), table, TRUE, TRUE, 0);
+
+   color.red = 0;
+   color.green = 32768;
+   color.blue = 0;
+   gtk_widget_modify_bg (box, GTK_STATE_NORMAL, &color);
 
-   color.red = 32768;
-   color.green = 65535;
-   color.blue = 65535;
-   gtk_databox_set_background_color (GTK_DATABOX (box), color);
    X = g_new0 (gfloat, POINTS);
    Y = g_new0 (gfloat, POINTS);
 
    for (i = 0; i < POINTS; i++)
    {
       X[i] = i;
-      Y[i] = 100. * sin (i * 2 * PI / POINTS);
+      Y[i] = 100. * sin (i * 2 * G_PI / POINTS);
    }
    color.red = 0;
    color.green = 65535;
    color.blue = 0;
 
-   index = gtk_databox_data_add_x_y (GTK_DATABOX (box), POINTS,
-				     X, Y, color, GTK_DATABOX_POINTS, 3);
+   graph = gtk_databox_points_new (POINTS, X, Y, &color, 3);
+   gtk_databox_graph_add (GTK_DATABOX (box), graph);
+   
    Y = g_new0 (gfloat, POINTS);
 
    for (i = 0; i < POINTS; i++)
    {
-      Y[i] = 100. * cos (i * 2 * PI / POINTS);
+      Y[i] = 100. * cos (i * 2 * G_PI / POINTS);
    }
    color.red = 65535;
    color.green = 0;
    color.blue = 0;
 
-   gtk_databox_data_add_y (GTK_DATABOX (box), POINTS,
-			   Y, index, color, GTK_DATABOX_POINTS, 3);
+   graph = gtk_databox_points_new (POINTS, X, Y, &color, 3);
+   gtk_databox_graph_add (GTK_DATABOX (box), graph);
 
-   /* Here comes the grid stuff. 
-    * It might look a bit perverted at first glance, but it 
-    * has a lot of charme to be able to handle it this way
-    */
+   /* Here we start with the first grid */
    color.red = 0;
    color.green = 0;
    color.blue = 65535;
 
-   index = gtk_databox_data_add_y (GTK_DATABOX (box), POINTS,
-				   Y, index, color, GTK_DATABOX_GRID, 2);
+   graph = gtk_databox_grid_new (7, 7, &color, 2);
+   gtk_databox_graph_add (GTK_DATABOX (box), graph);
 
-   gtk_databox_data_set_grid_config (GTK_DATABOX (box), index, 7, 7);
+   color.red = 32000;
+   color.green = 0;
+   color.blue = 0;
 
+   graph = gtk_databox_grid_new (15, 15, &color, 2);
+   gtk_databox_graph_add (GTK_DATABOX (box), graph);
 
-   gtk_databox_rescale (GTK_DATABOX (box));
-
-   gtk_box_pack_start (GTK_BOX (box1), box, TRUE, TRUE, 0);
-
+   gtk_databox_auto_rescale (GTK_DATABOX (box), 0.05);
+         
    separator = gtk_hseparator_new ();
    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, TRUE, 0);
 
