@@ -19,11 +19,9 @@
 
 #include <gtk/gtk.h>
 #include <gtkdatabox.h>
+#include <gtkdatabox_points.h>
+#include <gtkdatabox_lines.h>
 #include <math.h>
-/* Some versions of math.h have a PI problem... */
-#ifndef PI
-#define PI 3.14159265358979323846
-#endif
 
 #define POINTS 2000
 
@@ -35,7 +33,7 @@ static gfloat *lissajousX = NULL;
 static gfloat *lissajousY = NULL;
 
 static gint lissajous_idle = 0;
-static gfloat lissajous_frequency = 3. * PI / 2.;
+static gfloat lissajous_frequency = 3. * G_PI / 2.;
 static GtkWidget *lissajous_label = NULL;
 static guint lissajous_counter = 0;
 
@@ -51,13 +49,13 @@ lissajous_idle_func (GtkDatabox * box)
       return FALSE;
 
    lissajous_frequency += 0.001;
-   off = lissajous_counter * 4 * PI / POINTS;
+   off = lissajous_counter * 4 * G_PI / POINTS;
 
    freq = 14 + 10 * sin (lissajous_frequency);
    for (i = 0; i < POINTS; i++)
    {
-      lissajousX[i] = 100. * sin (i * 4 * PI / POINTS + off);
-      lissajousY[i] = 100. * cos (i * freq * PI / POINTS + off);
+      lissajousX[i] = 100. * sin (i * 4 * G_PI / POINTS + off);
+      lissajousY[i] = 100. * cos (i * freq * G_PI / POINTS + off);
    }
 
 
@@ -78,7 +76,9 @@ create_lissajous (void)
    GtkWidget *close_button;
    GtkWidget *box;
    GtkWidget *label;
+   GtkWidget *table;
    GtkWidget *separator;
+   GtkDataboxGraph *graph;
    GdkColor color;
    gint i;
 
@@ -86,10 +86,10 @@ create_lissajous (void)
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_set_size_request (window, 300, 300);
 
-   g_signal_connect (GTK_OBJECT (window), "destroy",
-		     GTK_SIGNAL_FUNC (gtk_main_quit), NULL);
+   g_signal_connect (G_OBJECT (window), "destroy",
+		     G_CALLBACK (gtk_main_quit), NULL);
 
-   gtk_window_set_title (GTK_WINDOW (window), "Databox: Lissajous Example");
+   gtk_window_set_title (GTK_WINDOW (window), "GtkDatabox: Lissajous Example");
    gtk_container_set_border_width (GTK_CONTAINER (window), 0);
 
    box1 = gtk_vbox_new (FALSE, 0);
@@ -108,37 +108,39 @@ create_lissajous (void)
    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, FALSE, 0);
 
    lissajous_idle = 0;
-   lissajous_frequency = 3. * PI / 2.;
+   lissajous_frequency = 3. * G_PI / 2.;
    lissajous_counter = 0;
 
-   box = gtk_databox_new ();
-   g_signal_connect (GTK_OBJECT (box), "destroy",
-		     GTK_SIGNAL_FUNC (gtk_databox_data_destroy_all), NULL);
+   /* Create a GtkDatabox widget along with scrollbars and rulers */
+   gtk_databox_create_box_with_scrollbars_and_rulers (&box, &table, 
+                                                      TRUE, TRUE,
+                                                      TRUE, TRUE);
+                                      
+   gtk_box_pack_start (GTK_BOX (box1), table, TRUE, TRUE, 0);
+
+   color.red = 0;
+   color.green = 0;
+   color.blue = 32768;
+
+   gtk_widget_modify_bg (box, GTK_STATE_NORMAL, &color);
 
    lissajousX = g_new0 (gfloat, POINTS);
    lissajousY = g_new0 (gfloat, POINTS);
 
    for (i = 0; i < POINTS; i++)
    {
-      lissajousX[i] = 100. * sin (i * 4 * PI / POINTS);
-      lissajousY[i] = 100. * cos (i * 4 * PI / POINTS);
+      lissajousX[i] = 100. * sin (i * 4 * G_PI / POINTS);
+      lissajousY[i] = 100. * cos (i * 4 * G_PI / POINTS);
    }
    color.red = 65535;
    color.green = 65535;
    color.blue = 0;
 
-   gtk_databox_data_add_x_y (GTK_DATABOX (box), POINTS,
-			     lissajousX, lissajousY, color,
-			     GTK_DATABOX_LINES, 0);
+   graph = gtk_databox_lines_new (POINTS, lissajousX, lissajousY,
+                                   &color, 1);
+   gtk_databox_graph_add (GTK_DATABOX (box), graph);
 
-   color.red = 0;
-   color.green = 0;
-   color.blue = 32768;
-   gtk_databox_set_background_color (GTK_DATABOX (box), color);
-
-   gtk_databox_rescale (GTK_DATABOX (box));
-
-   gtk_box_pack_start (GTK_BOX (box1), box, TRUE, TRUE, 0);
+   gtk_databox_auto_rescale (GTK_DATABOX (box), 0.05);
 
    separator = gtk_hseparator_new ();
    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, TRUE, 0);
@@ -148,14 +150,14 @@ create_lissajous (void)
    gtk_box_pack_end (GTK_BOX (box1), box2, FALSE, TRUE, 0);
    close_button = gtk_button_new_with_label ("close");
 
-   g_signal_connect_swapped (GTK_OBJECT (close_button), "clicked",
-			     GTK_SIGNAL_FUNC (gtk_main_quit),
-			     GTK_OBJECT (box));
+   g_signal_connect_swapped (G_OBJECT (close_button), "clicked",
+			     G_CALLBACK (gtk_main_quit),
+			     G_OBJECT (box));
 
    gtk_box_pack_start (GTK_BOX (box2), close_button, TRUE, TRUE, 0);
    GTK_WIDGET_SET_FLAGS (close_button, GTK_CAN_DEFAULT);
    gtk_widget_grab_default (close_button);
-   lissajous_idle = gtk_idle_add ((GtkFunction) lissajous_idle_func, box);
+   lissajous_idle = g_idle_add ((GSourceFunc) lissajous_idle_func, box);
 
    gtk_widget_show_all (window);
 }
