@@ -19,11 +19,8 @@
 
 #include <gtk/gtk.h>
 #include <gtkdatabox.h>
+#include <gtkdatabox_points.h>
 #include <math.h>
-/* Some versions of math.h have a PI problem... */
-#ifndef PI
-#define PI 3.14159265358979323846
-#endif
 
 #define POINTS 2000
 
@@ -31,15 +28,25 @@
  *  databox signals
  *----------------------------------------------------------------*/
 
+const gchar *
+get_name_of_current_signal (gpointer instance)
+{
+   GSignalInvocationHint * ihint;
+
+   ihint = g_signal_get_invocation_hint (instance);
+
+   return g_signal_name (ihint->signal_id);
+}
+
 /* 
  * Signal handlers 
  */
 static gint
-handle_signal_zoomed (GtkDatabox * box,
-		      GtkDataboxValue * top_left,
-		      GtkDataboxValue * bottom_right, void *unused)
+handle_signal_zoomed (GtkDatabox *box,
+		      GtkDataboxValue *top_left,
+		      GtkDataboxValue *bottom_right, void *unused)
 {
-   printf ("Name of the signal: gtk_databox_zoomed\n");
+   printf ("Name of the signal: %s\n", get_name_of_current_signal (box));
    printf ("It tells you that the GtkDatabox has zoomed to the following\n");
    printf
       ("rectangle (data coordindates only, pixels don't make sense here):\n");
@@ -49,72 +56,18 @@ handle_signal_zoomed (GtkDatabox * box,
    return 0;
 }
 
-/*static gint
-handle_signal_marked (GtkDatabox * box,
-		      GtkDataboxCoord * marked, void *unused)
-{
-   GtkDataboxValue value;
-
-   gtk_databox_data_get_value (box, *marked, &value);
-
-   printf ("Name of the signal: gtk_databox_marked\n");
-   printf
-      ("It tells you that someone has clicked at the following coordinates:\n");
-   printf ("Pixel: (X,Y)=(%d, %d)\n", marked->x, marked->y);
-   printf ("Data: (X,Y)=(%g, %g)\n", value.x, value.y);
-
-   return 0;
-}
-
 static gint
-handle_signal_selection_started (GtkDatabox * box,
-				 GtkDataboxCoord * marked, void *unused)
-{
-   GtkDataboxValue value;
-
-   gtk_databox_data_get_value (box, *marked, &value);
-
-   printf ("Name of the signal: gtk_databox_selection_started\n");
-   printf ("It tells you that someone has started a selection at\n");
-   printf ("the following coordinates:\n");
-   printf ("Pixel: (X,Y)=(%d, %d)\n", marked->x, marked->y);
-   printf ("Data: (X,Y)=(%g, %g)\n", value.x, value.y);
-   return 0;
-}
-
-static gint
-handle_signal_selection_changed (GtkDatabox * box,
-				 GtkDataboxCoord * marked,
-				 GtkDataboxCoord * select, void *unused)
+handle_signal_selection_stopped (GtkDatabox *box,
+				 GtkDataboxCoord *marked,
+				 GtkDataboxCoord *select, void *unused)
 {
    GtkDataboxValue value1;
    GtkDataboxValue value2;
 
-   gtk_databox_data_get_value (box, *marked, &value1);
-   gtk_databox_data_get_value (box, *select, &value2);
+   value1 = gtk_databox_value_from_coord (box, *marked);
+   value2 = gtk_databox_value_from_coord (box, *select);
 
-   printf ("Name of the signal: gtk_databox_selection_changed\n");
-   printf ("It tells you that a user has changed the selection box.\n");
-   printf ("Pixel: corner1 (X,Y)=(%d, %d), corner2 (X,Y)=(%d, %d)\n",
-	   marked->x, marked->y, select->x, select->y);
-   printf ("Data: corner1 (X,Y)=(%g, %g), corner2 (X,Y)=(%g, %g)\n",
-	   value1.x, value1.y, value2.x, value2.y);
-
-   return 0;
-}*/
-
-static gint
-handle_signal_selection_stopped (GtkDatabox * box,
-				 GtkDataboxCoord * marked,
-				 GtkDataboxCoord * select, void *unused)
-{
-   GtkDataboxValue value1;
-   GtkDataboxValue value2;
-
-   gtk_databox_data_get_value (box, *marked, &value1);
-   gtk_databox_data_get_value (box, *select, &value2);
-
-   printf ("Name of the signal: gtk_databox_selection_stopped\n");
+   printf ("Name of the signal: %s\n", get_name_of_current_signal (box));
    printf ("It tells you that the user has stopped changing the selection\n");
    printf ("box, i.e. the mouse button is released now.\n");
    printf ("Pixel: corner1 (X,Y)=(%d, %d), corner2 (X,Y)=(%d, %d)\n",
@@ -126,9 +79,18 @@ handle_signal_selection_stopped (GtkDatabox * box,
 }
 
 static gint
-handle_signal_selection_cancelled (GtkDatabox * box, void *unused)
+handle_signal_selection_started (GtkDatabox *box, void *unused)
 {
-   printf ("Name of the signal: gtk_databox_selection_cancelled\n");
+   printf ("Name of the signal: gtk_databox_selection_started\n");
+   printf ("It tells you that the user has started a the selection box\n");
+
+   return 0;
+}
+
+static gint
+handle_signal_selection_cancelled (GtkDatabox *box, void *unused)
+{
+   printf ("Name of the signal: %s\n", get_name_of_current_signal (box));
    printf ("It tells you that the user has dismissed the selection box\n");
 
    return 0;
@@ -162,20 +124,19 @@ show_entry (GtkWidget *hbox, gchar *text)
   return entry;
 }
 
-static void
-show_motion_notify_cb(GtkWidget *widget, GdkEventMotion *event, GtkWidget **entries)
+static gint
+show_motion_notify_cb(GtkWidget *widget, GdkEventMotion *event, 
+                      GtkWidget **entries)
 {
   GtkDataboxCoord coord;
   GtkDataboxValue value;
-  GdkModifierType state;
   gchar *text;
   GtkDatabox *box = GTK_DATABOX (entries [SHOW_BOX] );
 
   coord.x = event->x;
   coord.y = event->y;
-  state = event->state;
 
-  gtk_databox_data_get_value(box, coord, &value);
+  value = gtk_databox_value_from_coord (box, coord);
 
   text=g_strdup_printf("%g", value.x);
   gtk_entry_set_text(GTK_ENTRY(entries[SHOW_ACTUAL_X]), text);
@@ -183,33 +144,47 @@ show_motion_notify_cb(GtkWidget *widget, GdkEventMotion *event, GtkWidget **entr
   text=g_strdup_printf("%g", value.y);
   gtk_entry_set_text(GTK_ENTRY(entries[SHOW_ACTUAL_Y]), text);
   g_free((gpointer) text);
+
+  return FALSE;
 }
 
-static void
-show_marked_cb(GtkDatabox *box, GtkDataboxCoord *marked, GtkWidget **entries)
+static gint
+show_button_press_cb (GtkDatabox *box, GdkEventButton *event, 
+                      GtkWidget **entries)
 {
-  GtkDataboxValue value;
-  gchar *text;
+   GtkDataboxCoord coord;
+   GtkDataboxValue value;
+   gchar *text;
+ 
+   if (!(event->button == 1 || event->button == 2))
+      return FALSE;
 
-  gtk_databox_data_get_value(box, *marked, &value);
+   coord.x = event->x;
+   coord.y = event->y;
+     
+   value = gtk_databox_value_from_coord (box, coord);
+ 
+   text=g_strdup_printf("%g", value.x);
+   gtk_entry_set_text(GTK_ENTRY(entries[SHOW_MARKED_X]), text);
+   g_free((gpointer) text);
+   text=g_strdup_printf("%g", value.y);
+   gtk_entry_set_text(GTK_ENTRY(entries[SHOW_MARKED_Y]), text);
+   g_free((gpointer) text);
 
-  text=g_strdup_printf("%g", value.x);
-  gtk_entry_set_text(GTK_ENTRY(entries[SHOW_MARKED_X]), text);
-  g_free((gpointer) text);
-  text=g_strdup_printf("%g", value.y);
-  gtk_entry_set_text(GTK_ENTRY(entries[SHOW_MARKED_Y]), text);
-  g_free((gpointer) text);
+   return FALSE;
 }
 
 static void
-show_changed_cb(GtkDatabox *box, GtkDataboxCoord *marked, GtkDataboxCoord *select, GtkWidget **entries)
+show_changed_cb(GtkDatabox *box, 
+                GtkDataboxCoord *marked, 
+                GtkDataboxCoord *select, GtkWidget **entries)
 {
   GtkDataboxValue value1;
   GtkDataboxValue value2;
   gchar *text;
 
-  gtk_databox_data_get_value(box, *marked, &value1);
-  gtk_databox_data_get_value(box, *select, &value2);
+  value1 = gtk_databox_value_from_coord (box, *marked);
+  value2 = gtk_databox_value_from_coord (box, *select);
 
   text=g_strdup_printf("%g", value2.x-value1.x);
   gtk_entry_set_text(GTK_ENTRY(entries[SHOW_DELTA_X]), text);
@@ -236,11 +211,12 @@ create_signals (void)
    GtkWidget *box2;
    GtkWidget *close_button;
    GtkWidget *box;
+   GtkWidget *table;
    GtkWidget *label;
    GtkWidget *separator;
-   gint index;
    gfloat *X;
    gfloat *Y;
+   GtkDataboxGraph *graph;
    GdkColor color;
    gint i;
    GtkWidget **entries;
@@ -251,8 +227,8 @@ create_signals (void)
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_set_size_request (window, 500, 500);
 
-   g_signal_connect (GTK_OBJECT (window), "destroy",
-		     GTK_SIGNAL_FUNC (gtk_main_quit), NULL);
+   g_signal_connect (G_OBJECT (window), "destroy",
+		     G_CALLBACK (gtk_main_quit), NULL);
 
    gtk_window_set_title (GTK_WINDOW (window), "GtkDatabox: Signals Examples");
    gtk_container_set_border_width (GTK_CONTAINER (window), 0);
@@ -262,7 +238,7 @@ create_signals (void)
 
    label =
       gtk_label_new
-      ("The output on the shell shows you the information that\nyou can get by using signals.\n\nSee basics for a usage of this window...");
+      ("The output on the shell and in the text boxes below\nshow you the information that you can get\n by using signals.\n\nSee basics for a usage of this window...");
 
    gtk_box_pack_start (GTK_BOX (box1), label, FALSE, FALSE, 0);
    separator = gtk_hseparator_new ();
@@ -278,10 +254,14 @@ create_signals (void)
    entries[SHOW_DELTA_X]  = show_entry (hbox, "Delta X");
    entries[SHOW_DELTA_Y]  = show_entry (hbox, "Delta Y");
 
-   box = gtk_databox_new ();
+   /* Create a GtkDatabox widget along with scrollbars and rulers */
+   gtk_databox_create_box_with_scrollbars_and_rulers (&box, &table, 
+                                                      TRUE, TRUE,
+                                                      TRUE, TRUE);
+
+   gtk_box_pack_start (GTK_BOX (box1), table, TRUE, TRUE, 0);
+                                      
    entries[SHOW_BOX]  = box;
-   g_signal_connect (GTK_OBJECT (box), "destroy",
-		     GTK_SIGNAL_FUNC (gtk_databox_data_destroy_all), NULL);
 
    X = g_new0 (gfloat, POINTS);
    Y = g_new0 (gfloat, POINTS);
@@ -289,29 +269,29 @@ create_signals (void)
    for (i = 0; i < POINTS; i++)
    {
       X[i] = i;
-      Y[i] = 100. * sin (i * 2 * PI / POINTS);
+      Y[i] = 100. * sin (i * 2 * G_PI / POINTS);
    }
    color.red = 0;
    color.green = 65535;
    color.blue = 0;
 
-   index = gtk_databox_data_add_x_y (GTK_DATABOX (box), POINTS,
-				     X, Y, color, GTK_DATABOX_POINTS, 1);
+   graph = gtk_databox_points_new (POINTS, X, Y, &color, 1);
+   gtk_databox_graph_add (GTK_DATABOX (box), graph);
+
    Y = g_new0 (gfloat, POINTS);
 
    for (i = 0; i < POINTS; i++)
    {
-      Y[i] = 100. * cos (i * 2 * PI / POINTS);
+      Y[i] = 100. * cos (i * 2 * G_PI / POINTS);
    }
    color.red = 65535;
    color.green = 0;
    color.blue = 0;
 
-   gtk_databox_data_add_y (GTK_DATABOX (box), POINTS,
-			   Y, index, color, GTK_DATABOX_POINTS, 1);
-   gtk_databox_rescale (GTK_DATABOX (box));
+   graph = gtk_databox_points_new (POINTS, X, Y, &color, 1);
+   gtk_databox_graph_add (GTK_DATABOX (box), graph);
 
-   gtk_box_pack_start (GTK_BOX (box1), box, TRUE, TRUE, 0);
+   gtk_databox_auto_rescale (GTK_DATABOX (box), 0.05);
 
    separator = gtk_hseparator_new ();
    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, TRUE, 0);
@@ -320,34 +300,34 @@ create_signals (void)
    gtk_container_set_border_width (GTK_CONTAINER (box2), 10);
    gtk_box_pack_end (GTK_BOX (box1), box2, FALSE, TRUE, 0);
    close_button = gtk_button_new_with_label ("close");
-   g_signal_connect_swapped (GTK_OBJECT (close_button), "clicked",
-			     GTK_SIGNAL_FUNC (gtk_main_quit),
-			     GTK_OBJECT (box));
+   g_signal_connect_swapped (G_OBJECT (close_button), "clicked",
+			     G_CALLBACK (gtk_main_quit),
+			     G_OBJECT (box));
    gtk_box_pack_start (GTK_BOX (box2), close_button, TRUE, TRUE, 0);
    GTK_WIDGET_SET_FLAGS (close_button, GTK_CAN_DEFAULT);
    gtk_widget_grab_default (close_button);
 
-   g_signal_connect (GTK_OBJECT (box), "gtk_databox_zoomed",
-		     GTK_SIGNAL_FUNC (handle_signal_zoomed), 
+   g_signal_connect (G_OBJECT (box), "databox_zoomed",
+		     G_CALLBACK (handle_signal_zoomed), 
                      NULL);
-   g_signal_connect (GTK_OBJECT (box), "gtk_databox_selection_stopped",
-		     GTK_SIGNAL_FUNC (handle_signal_selection_stopped), 
+   g_signal_connect (G_OBJECT (box), "databox_selection_started",
+		     G_CALLBACK (handle_signal_selection_started), 
                      NULL);
-   g_signal_connect (GTK_OBJECT (box), "gtk_databox_selection_cancelled",
-		     GTK_SIGNAL_FUNC (handle_signal_selection_cancelled),
+   g_signal_connect (G_OBJECT (box), "databox_selection_stopped",
+		     G_CALLBACK (handle_signal_selection_stopped), 
+                     NULL);
+   g_signal_connect (G_OBJECT (box), "databox_selection_cancelled",
+		     G_CALLBACK (handle_signal_selection_cancelled),
 		     NULL);
-   g_signal_connect (GTK_OBJECT (GTK_DATABOX (box)->draw), 
+   g_signal_connect (G_OBJECT (box), 
                      "motion_notify_event",
-                     GTK_SIGNAL_FUNC (show_motion_notify_cb),
+                     G_CALLBACK (show_motion_notify_cb),
                      entries);
-   g_signal_connect (GTK_OBJECT (box), "gtk_databox_marked",
-                     GTK_SIGNAL_FUNC (show_marked_cb),
+   g_signal_connect (G_OBJECT (box), "button_press_event",
+                     G_CALLBACK (show_button_press_cb),
                      entries);
-   g_signal_connect (GTK_OBJECT (box), "gtk_databox_selection_started",
-                     GTK_SIGNAL_FUNC (show_marked_cb),
-                     entries);
-   g_signal_connect (GTK_OBJECT (box), "gtk_databox_selection_changed",
-                            GTK_SIGNAL_FUNC (show_changed_cb),
+   g_signal_connect (G_OBJECT (box), "databox_selection_changed",
+                            G_CALLBACK (show_changed_cb),
                             entries);
 
    gtk_widget_show_all (window);
